package
Version:
v0.0.0-...-c1a1ff6
Opens a new window with list of versions in this module.
Published: Apr 7, 2021
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Servers []interface{} `json:"servers"`
}
type HostHTTP struct {
Hostname string `json:"hostname"`
Port uint `json:"port"`
Path string `json:"path"`
Weight uint8 `json:"weight"`
}
type HostTCPUDP struct {
Hostname string `json:"hostname"`
Port uint `json:"port"`
Weight uint8 `json:"weight"`
}
type ServerHTTPS struct {
Type string `json:"type"`
Hosts []HostHTTP `json:"hosts"`
ServerName string `json:"name"`
ServerPort uint `json:"port"`
Certificate string `json:"ssl-crt"`
Key string `json:"ssl-key"`
}
type ServerTCP struct {
Type string `json:"type"`
Hosts []HostTCPUDP `json:"hosts"`
Port uint `json:"port"`
}
type ServerUDP struct {
Type string `json:"type"`
Hosts []HostTCPUDP `json:"hosts"`
Port uint `json:"port"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.